@@ -16,26 +16,35 @@ from ironicclient.common.apiclient.exceptions import *  # noqa
 
 # NOTE(akurilin): This alias is left here since v.0.1.3 to support backwards
 # compatibility.
-InvalidEndpoint = EndpointException
-CommunicationError = ConnectionRefused
-HTTPBadRequest = BadRequest
-HTTPInternalServerError = InternalServerError
-HTTPNotFound = NotFound
-HTTPServiceUnavailable = ServiceUnavailable
+InvalidEndpoint = exceptions.EndpointException
+CommunicationError = exceptions.ConnectionRefused
+HTTPBadRequest = exceptions.BadRequest
+HTTPInternalServerError = exceptions.InternalServerError
+HTTPNotFound = exceptions.NotFound
+HTTPServiceUnavailable = exceptions.ServiceUnavailable
 
 
-class AmbiguousAuthSystem(ClientException):
+class AmbiguousAuthSystem(exceptions.ClientException):
     """Could not obtain token and endpoint using provided credentials."""
     pass
 
+
 # Alias for backwards compatibility
 AmbigiousAuthSystem = AmbiguousAuthSystem
 
 
-class InvalidAttribute(ClientException):
+class InvalidAttribute(exceptions.ClientException):
     pass
 
 
+class StateTransitionFailed(exceptions.ClientException):
+    """Failed to reach a requested provision state."""
+
+
+class StateTransitionTimeout(exceptions.ClientException):
+    """Timed out while waiting for a requested provision state."""
+
+
 def from_response(response, message=None, traceback=None, method=None,
                   url=None):
     """Return an HttpError instance based on response from httplib/requests."""
