@@ -18,8 +18,8 @@ import copy
 from unittest import mock
 
 from osc_lib.tests import utils as osctestutils
-from osc_lib import utils as oscutils
 
+from ironicclient.common import utils
 from ironicclient import exc
 from ironicclient.osc.v1 import baremetal_port
 from ironicclient.tests.unit.osc.v1 import fakes as baremetal_fakes
@@ -299,6 +299,33 @@ class TestCreateBaremetalPort(TestBaremetalPort):
 
         self.baremetal_mock.port.create.assert_called_once_with(**args)
 
+    def test_baremetal_port_create_description(self):
+        arglist = [
+            baremetal_fakes.baremetal_port_address,
+            '--node', baremetal_fakes.baremetal_uuid,
+            '--description', 'Public Network'
+        ]
+
+        verifylist = [
+            ('node_uuid', baremetal_fakes.baremetal_uuid),
+            ('address', baremetal_fakes.baremetal_port_address),
+            ('description', 'Public Network')
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # DisplayCommandBase.take_action() returns two tuples
+        self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        args = {
+            'address': baremetal_fakes.baremetal_port_address,
+            'node_uuid': baremetal_fakes.baremetal_uuid,
+            'description': 'Public Network'
+        }
+
+        self.baremetal_mock.port.create.assert_called_once_with(**args)
+
 
 class TestShowBaremetalPort(TestBaremetalPort):
     def setUp(self):
@@ -466,6 +493,18 @@ class TestBaremetalPortUnset(TestBaremetalPort):
             'port',
             [{'path': '/name', 'op': 'remove'}])
 
+    def test_baremetal_port_unset_description(self):
+        arglist = ['port', '--description']
+        verifylist = [('port', 'port'),
+                      ('description', True)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.baremetal_mock.port.update.assert_called_once_with(
+            'port',
+            [{'path': '/description', 'op': 'remove'}])
+
 
 class TestBaremetalPortSet(TestBaremetalPort):
     def setUp(self):
@@ -650,6 +689,22 @@ class TestBaremetalPortSet(TestBaremetalPort):
             [{'path': '/name', 'value': 'portname2',
               'op': 'add'}])
 
+    def test_baremetal_port_set_description(self):
+        arglist = [
+            baremetal_fakes.baremetal_port_uuid,
+            '--description', 'Public Network']
+        verifylist = [
+            ('port', baremetal_fakes.baremetal_port_uuid),
+            ('description', 'Public Network')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.baremetal_mock.port.update.assert_called_once_with(
+            baremetal_fakes.baremetal_port_uuid,
+            [{'path': '/description', 'value': 'Public Network',
+              'op': 'add'}])
+
 
 class TestBaremetalPortDelete(TestBaremetalPort):
     def setUp(self):
@@ -813,7 +868,7 @@ class TestBaremetalPortList(TestBaremetalPort):
             baremetal_fakes.baremetal_port_uuid,
             baremetal_fakes.baremetal_port_address,
             '',
-            oscutils.format_dict(baremetal_fakes.baremetal_port_extra),
+            utils.HashColumn(baremetal_fakes.baremetal_port_extra),
             baremetal_fakes.baremetal_uuid,
             '',
             '',
