@@ -29,7 +29,9 @@ PORT = {'uuid': '11111111-2222-3333-4444-555555555555',
         'local_link_connection': {},
         'portgroup_uuid': '55555555-4444-3333-2222-111111111111',
         'physical_network': 'physnet1',
-        'extra': {}}
+        'is_smartnic': False,
+        'extra': {},
+        'name': 'port_name'}
 
 PORT2 = {'uuid': '55555555-4444-3333-2222-111111111111',
          'node_uuid': '55555555-4444-3333-2222-111111111111',
@@ -38,7 +40,9 @@ PORT2 = {'uuid': '55555555-4444-3333-2222-111111111111',
          'local_link_connection': {},
          'portgroup_uuid': '55555555-4444-3333-2222-111111111111',
          'physical_network': 'physnet2',
-         'extra': {}}
+         'is_smartnic': True,
+         'extra': {},
+         'name': 'port2_name'}
 
 CREATE_PORT = copy.deepcopy(PORT)
 del CREATE_PORT['uuid']
@@ -303,6 +307,8 @@ class PortManagerTest(testtools.TestCase):
                          port.local_link_connection)
         self.assertEqual(PORT['portgroup_uuid'], port.portgroup_uuid)
         self.assertEqual(PORT['physical_network'], port.physical_network)
+        self.assertEqual(PORT['is_smartnic'], port.is_smartnic)
+        self.assertEqual(PORT['name'], port.name)
 
     def test_ports_show_by_address(self):
         port = self.mgr.get_by_address(PORT['address'])
@@ -319,6 +325,7 @@ class PortManagerTest(testtools.TestCase):
                          port.local_link_connection)
         self.assertEqual(PORT['portgroup_uuid'], port.portgroup_uuid)
         self.assertEqual(PORT['physical_network'], port.physical_network)
+        self.assertEqual(PORT['is_smartnic'], port.is_smartnic)
 
     def test_port_show_fields(self):
         port = self.mgr.get(PORT['uuid'], fields=['uuid', 'address'])
